@@ -234,8 +234,8 @@ struct MyHandler {
 
 impl DittoAuthenticationEventHandler for MyHandler {
     fn authentication_required(&self, auth: dittolive_ditto::auth::DittoAuthenticator) {
-        if let Err(e) = auth.login_with_token(&self.token, &self.provider) {
-            ::log::error!("Login Failed {}", &e);
+        if let Err(e) = auth.login_with_token_and_feedback(&self.token, &self.provider) {
+            ::log::error!("Login Failed {:?}", &e);
         }
     }
 
