@@ -56,31 +56,12 @@ impl ScopedCollection<'_, '_> {
         id: Option<&DocumentId>,
         write_strategy: WriteStrategy,
     ) -> Result<&'_ DocumentId, DittoError> {
-        let doc = {
-            let id: Option<c_slice::Ref<'_, u8>> = id.map(|id| id.as_ref().into());
-            match write_strategy {
-                WriteStrategy::InsertDefaultIfAbsent => unsafe {
-                    ffi_sdk::ditto_document_new_cbor_default_data(cbor.into(), id)
-                },
-                _ => unsafe {
-                    ffi_sdk::ditto_document_new_cbor(cbor.into(), id, self.batch.store.site_id)
-                },
-            }
-            .ok_or(ErrorKind::InvalidInput)?
-        };
-        let write_strategy_rs = write_strategy.as_write_strategy_rs();
-        let doc_id = unsafe {
-            ffi_sdk::ditto_collection_insert(
-                &*self.batch.store.ditto,
-                self.collection_name.as_ref(),
-                self.batch.txn,
-                doc,
-                write_strategy_rs,
-            )
-            .ok_or(ErrorKind::InvalidInput)?
-            .to::<Box<[u8]>>()
-            .into()
+        let coll = Collection {
+            ditto: self.batch.store.ditto.clone(),
+            collection_name: self.collection_name.clone(),
         };
+        let doc_id = coll.insert_cbor(cbor, id, write_strategy, Some(self.batch.txn))?;
+
         self.batch.results.push(WriteTransactionResult {
             doc_id,
             collection_name: self.collection_name.to_owned(),
