@@ -117,7 +117,9 @@ pub struct LoginSource {
 
 impl DittoAuthenticationEventHandler for LoginSource {
     fn authentication_required(&self, auth: DittoAuthenticator) {
-        auth.login_with_token(&self.token, &self.provider).unwrap()
+        let _ = auth
+            .login_with_token_and_feedback(&self.token, &self.provider)
+            .unwrap();
     }
 
     fn authentication_expiring_soon(&self, _auth: DittoAuthenticator, seconds_remaining: Duration) {
